@@ -8,6 +8,7 @@ from kvirt.cluster import k3s
 from kvirt.cluster import kubeadm
 from kvirt.cluster import microshift
 from kvirt.cluster import openshift
+from kvirt.cluster import rke2
 from kvirt import common
 from kvirt.common import error, pprint, warning, container_mode, ssh, scp, NoAliasDumper
 from kvirt import defaults as kdefaults
@@ -33,6 +34,10 @@ def other_client(profile, clients):
     return False
 
 
+def libvirt_macosx():
+    return which('brew') is not None and 'libvirt started' in os.popen('brew services list').read()
+
+
 class Kbaseconfig:
     def __init__(self, client=None, containerclient=None, debug=False, quiet=False, offline=False):
         self.debug = debug
@@ -75,7 +80,7 @@ class Kbaseconfig:
                and not os.path.exists('/var/run/libvirt/virtqemud-sock'):
                 if os.path.exists('/i_am_a_container') and os.environ.get('KUBERNETES_SERVICE_HOST') is not None:
                     _type = 'kubevirt'
-                else:
+                elif not libvirt_macosx():
                     error("No configuration found nor local hypervisor. Is libvirt running?")
                     sys.exit(1)
             self.ini = {'default': {'client': defaultclient}, defaultclient:
@@ -1060,6 +1065,11 @@ class Kbaseconfig:
         inputfile = f'{plandir}/ctlplanes.yml'
         self.info_plan(inputfile, quiet=quiet, web=web)
 
+    def info_kube_rke2(self, quiet, web=False):
+        plandir = os.path.dirname(rke2.create.__code__.co_filename)
+        inputfile = f'{plandir}/ctlplanes.yml'
+        self.info_plan(inputfile, quiet=quiet, web=web)
+
     def info_openshift_sno(self, quiet, web=False):
         plandir = os.path.dirname(openshift.create.__code__.co_filename)
         inputfile = f'{plandir}/sno.yml'
