@@ -170,6 +170,9 @@ $ kcli create vm -i ubuntu-minimal-2204-lts -P gpus=['{"type": "nvidia-tesla-t4"
 
 # Create 3 vm to emulate baremetal
 $ kcli create vm -P start=false -P memory=20480 -P numcpus=16 -P disks=[200] -P uefi=true -P nets=[default] -c 3 myclu
+
+# Create an sriov enabled vm (on KVM only)
+$ kcli create vm -i centos9stream -P nets=['{"name": "default"}','{"name": "default", "sriov": "true"}']
 """
 
 vmconsole = """# Open a graphical console for vm ( only shows the command if using container)
@@ -257,6 +260,16 @@ $ kcli create kube openshift -P ctlplanes=1 -P workers=2 myopenshift
 $ kcli create kube openshift --paramfile=myparameters.yml myopenshift
 """
 
+kuberke2create = """# Create a kube rke2 instance named mykube with default values
+$ kcli create kube rke2 myrke2
+
+# Do the same with workers
+$ kcli create kube rke2 -P workers=2 myrke2
+
+# Use a parameter file
+$ kcli create kube rke2 --paramfile=myparameters.yml myrke2
+"""
+
 openshiftsnocreate = """# Create an SNO openshift iso named mysno with default values
 $ kcli create openshift-sno myopenshift
 
@@ -319,24 +332,24 @@ $ kcli create openshift-iso -P nets=['{"ip":"192.168.0.8","netmask":"24","gatewa
 $ kcli create openshift-iso -P extra_args="super_string_of_args" myopenshift.karmalabs.corp
 """
 
-disconnectedcreate = """# Generate an openshift disconnected vm for 4.15
-$ kcli create openshift-registry -P version=stable -P tag='4.15'
+disconnectedcreate = """# Generate an openshift disconnected vm for 4.16
+$ kcli create openshift-registry -P version=stable -P tag='4.16'
 
 # Do the same over an ipv4 network
-$ kcli create openshift-registry -P version=nightly -P tag='4.15' -P disconnected_ipv6_network=false
+$ kcli create openshift-registry -P version=nightly -P tag='4.16' -P disconnected_ipv6_network=false
 
-# Use specific version and add extra operators (from 4.15)
-$ kcli create openshift-registry -P version=nightly -P tag=4.15 -P disconnected_operators=[sriov-network-operator]
+# Use specific version and add extra operators (from 4.16)
+$ kcli create openshift-registry -P version=nightly -P tag=4.16 -P disconnected_operators=[sriov-network-operator]
 
 # Deploy registry without content
 $ kcli create openshift-registry -P disconnected_sync=false
 """
 
-disconnectedupdate = """# Update openshift disconnected registry for 4.15
-$ kcli update openshift-registry -P version=stable -P tag='4.15' -P disconnected_url=192.168.122.200.sslip.io:5000 myreg
+disconnectedupdate = """# Update openshift disconnected registry for 4.16
+$ kcli update openshift-registry -P version=stable -P tag='4.16' -P disconnected_url=192.168.122.200.sslip.io:5000 myreg
 
 # Update openshift disconnected registry taking parameter from existing cluster install named myopenshift
-$ kcli update openshift-registry -P tag='4.15.0' myopenshift
+$ kcli update openshift-registry -P tag='4.16.0' myopenshift
 """
 
 appopenshiftcreate = """# Deploy sriov network operator
@@ -498,6 +511,22 @@ $ kcli scale cluster openshift --workers 3 myclu
 $ kcli scale cluster openshift --ctlplanes 3 myclu
 """
 
+kuberke2scale = """# Scale workers from rke2 cluster myclu
+$ kcli scale cluster rke2 -P workers=3 myclu
+
+# Scale ctlplanes
+$ kcli scale cluster rke2 -P ctlplanes=3 myclu
+
+# Scale both ctlplanes and workers
+$ kcli scale cluster rke2 -P ctlplanes=3 -P workers=2 myclu
+
+# Alternative way to indicate workers
+$ kcli scale cluster rke2 --workers 3 myclu
+
+# Alternative way to indicate ctlplanes
+$ kcli scale cluster rke2 --ctlplanes 3 myclu
+"""
+
 networkupdate = """# Change network to isolated
 $ kcli update network mynetwork -i
 
